@@ -1,15 +1,7 @@
-/***************************************************************************
-    Copyright 2014 Inge Wallin <inge@lysator.liu.se>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Inge Wallin <inge@lysator.liu.se>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "dashboard.h"
 
@@ -28,7 +20,6 @@
 #include "parleydocument.h"
 #include "practice/themedbackgroundrenderer.h"
 #include "practice/imagewidget.h"
-#include "statistics/statisticsmainwindow.h"
 #include "statistics/statisticsmodel.h"
 
 #include "collection.h"
