@@ -1,23 +1,14 @@
-/***************************************************************************
-    Copyright 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
-    Copyright 2009 Daniel Laidig <d.laidig@gmx.de>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2009 Daniel Laidig <d.laidig@gmx.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "practicestatemachine.h"
 
 #include "parleydocument.h"
 
 #include "prefs.h"
-#include "abstractbackendmode.h"
 #include "comparisonbackendmode.h"
 #include "conjugationbackendmode.h"
 #include "examplesentencebackendmode.h"
