@@ -1,18 +1,10 @@
-/***************************************************************************
-    copyright     : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
-                    (C) 2005-2007 Peter Hedlund <peter.hedlund@kdemail.net>
-                    (C) 2007-2009 Frederik Gladhorn <gladhorn@kde.org>
-                    (C) 2014      Inge Wallin <inge@lysator.liu.se>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+    SPDX-FileCopyrightText: 2005-2007 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-FileCopyrightText: 2007-2009 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2014 Inge Wallin <inge@lysator.liu.se>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "sessionmanagerbase.h"
 
@@ -28,7 +20,6 @@
 
 // kdeedulibs
 #include <KEduVocLesson>
-#include <KEduVocExpression>
 #include <KEduVocDocument>
 
 // parley
