@@ -1,19 +1,10 @@
-/***************************************************************************
-    Copyright 2010 Daniel Laidig <laidig@kde.org>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Daniel Laidig <laidig@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "statustoggle.h"
 #include "themedbackgroundrenderer.h"
-#include "abstractfrontend.h"
 #include "statustogglebutton.h"
 
 #include <KLocalizedString>
